@@ -67,16 +67,17 @@ def authorize(permission):
     def wrap(func):
         def wrapped_func(request: Request):
             uid = user_info(request)["user_id"]
-            asset_id = request.json["asset_id"]
+            asset_type = permission.split(".")[0]
+            asset = getattr(assets, asset_type)(**request.json)
             granted = call(
                 "check_permission",
                 uid=uid,
-                asset=asset_id,
+                asset=asset,
                 permission=permission,
             )["granted"]
             if not granted:
                 abort(403)
-            request.headers["X-Authorized-Asset"] = f"assets/{asset_id}"
+            request.headers["X-Authorized-Asset"] = asset
             return func(request)
         return wrapped_func
     return wrap
